diff --git a/src/bin/installer_tui.rs b/src/bin/installer_tui.rs
index 1692ec53541969495ca1fa53a4376094de0ba689..8e3d0b8a526bb6c988eb0d5dcbb4ae896a125a52 100644
--- a/src/bin/installer_tui.rs
+++ b/src/bin/installer_tui.rs
@@ -298,10 +298,11 @@ fn main() {
             }
         };
 
         // Copy bootloader, filesystem.toml, and kernel
         let mut files = vec![
             "bootloader".to_string(),
             "filesystem.toml".to_string(),
+            "initfs".to_string(),
             "kernel".to_string()
         ];
@@ -298,10 +298,11 @@ fn main() {
         };
 
-        // Copy bootloader, filesystem.toml, and kernel
+        // Copy bootloader, filesystem.toml, initfs, and kernel
         let mut files = vec![
             "bootloader".to_string(),